@@ -63,24 +63,22 @@ def create_folder(folder_name, verbose=True):
 #            Visualizer             #
 #####################################
 class Visualizer:
-    def __init__(self, df, target_col, num_cols=None, cat_cols=None, ignore_cols=None, problem_type='classification'):
+    def __init__(self, df, target_col, num_cols=None, cat_cols=None, ignore_cols=[], problem_type='classification'):
         self.df           = df
         self.target_col   = target_col
         self.num_cols     = num_cols if num_cols != None else list(df.select_dtypes("number").columns)
         self.cat_cols     = cat_cols if cat_cols != None else list(df.select_dtypes('O').columns)
         self.ignore_cols  = ignore_cols
         self.problem_type = problem_type
-        self.version      = "0.0.8"
+        self.version      = "0.0.10"
 
         # Remove target_col from the numerical or categorical columns.
         if self.target_col in self.num_cols: self.num_cols.remove(self.target_col)
         if self.target_col in self.cat_cols: self.cat_cols.remove(self.target_col)
 
         # Remove the ignore columns
-        if self.ignore_cols == None:
-            continue
-        elif isinstance(self.ignore_cols, list):
-            if (self.num_cols is None or self.cat_cols is None) and self.ignore_cols:
+        if isinstance(self.ignore_cols, list):
+            if (self.num_cols is None or self.cat_cols is None):
                 for col in ignore_cols:
                     if col in self.num_cols: self.num_cols.remove(col)
                     if col in self.cat_cols: self.cat_cols.remove(col)
